class DomainBindings(object):

    """Manage Domain Bindings.
    """

    def __init__(self, client):
        self.client = client

    def create(self, domain, public_ip, include_www, include_wildcard, timeout, internal_port, object_id, content_type, options={}):
        """Creates a single domain binding.

        '/domain-bindings/' POST

        Args:
            domain: Domain Name
            public_ip: Public IP
            include_www: Include www. domain
            include_wildcard: Include all domains
            timeout: HTTP timeout in seconds
            internal_port: Internal TCP Port
            object_id: 
            content_type: 
        """
        body = options['body'] if 'body' in options else {}
        body['domain'] = domain
        body['public_ip'] = public_ip
        body['include_www'] = include_www
        body['include_wildcard'] = include_wildcard
        body['timeout'] = timeout
        body['internal_port'] = internal_port
        body['object_id'] = object_id
        body['content_type'] = content_type

        response = self.client.post('/domain-bindings/', body, options)

        return response

    def list(self, options={}):
        """List domain bindings.

        '/domain-bindings/' GET
        """
        body = options['query'] if 'query' in options else {}

        response = self.client.get('/domain-bindings/', body, options)

        return response

