from .http_client import HttpClient

# Assign all the api classes
from .api.account import Account
from .api.action import Action
from .api.actions import Actions
from .api.configs import Configs
from .api.domain import Domain
from .api.domains import Domains
from .api.domain_binding import DomainBinding
from .api.domain_bindings import DomainBindings
from .api.instance import Instance
from .api.instances import Instances
from .api.ssh_key import SshKey
from .api.ssh_keys import SshKeys
from .api.zone import Zone
from .api.zones import Zones


class Client(object):

    def __init__(self, auth={}, options={}):
        self.http_client = HttpClient(auth, options)

    def account(self):
        """Account Objects.
        """
        return Account(self.http_client)

    def action(self, id):
        """Manage Actions.

        Args:
            id: ID
        """
        return Action(id, self.http_client)

    def actions(self):
        """Manage Actions.
        """
        return Actions(self.http_client)

    def configs(self):
        """Manage Configs.
        """
        return Configs(self.http_client)

    def domain(self, name):
        """Manage Domains.

        Args:
            name: domain name
        """
        return Domain(name, self.http_client)

    def domains(self):
        """Manage Domains.
        """
        return Domains(self.http_client)

    def domain_binding(self, domain):
        """Manage Domain Bindings.

        Args:
            domain: Domain Name 
        """
        return DomainBinding(domain, self.http_client)

    def domain_bindings(self):
        """Manage Domain Bindings.
        """
        return DomainBindings(self.http_client)

    def instance(self, id):
        """Manage Instance.

        Args:
            id: ID
        """
        return Instance(id, self.http_client)

    def instances(self):
        """Manage Instances.
        """
        return Instances(self.http_client)

    def ssh_key(self, id):
        """Manage SSH Keys.

        Args:
            id: ID
        """
        return SshKey(id, self.http_client)

    def ssh_keys(self):
        """Manage SSH Keys.
        """
        return SshKeys(self.http_client)

    def zone(self, domain):
        """Manage Zones.

        Args:
            domain: Domain Name 
        """
        return Zone(domain, self.http_client)

    def zones(self):
        """Manage Zones.
        """
        return Zones(self.http_client)

